@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20190820';
+our $VERSION = '5.20190920';
 our %utilities;
 
 sub utilities {
@@ -1530,6 +1530,13 @@ my %delta = (
         removed => {
         }
     },
+    5.031004 => {
+        delta_from => 5.031003,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
